=== modified file 'lib/canonical/codehosting/__init__.py'
--- lib/canonical/codehosting/__init__.py	2009-03-24 20:40:19 +0000
+++ lib/canonical/codehosting/__init__.py	2009-03-27 00:09:15 +0000
@@ -50,6 +50,19 @@
 def load_optional_plugin(plugin_name):
     """Load the plugin named `plugin_name` from optionalbzrplugins/."""
     from bzrlib import plugins
+
+    if plugin_name == 'svn':
+        # This is utterly, utterly gross.  Yes.
+        class FuncTools:
+            @staticmethod
+            def partial(*args, **kw):
+                return None
+        import sys
+        sys.modules['functools'] = FuncTools
+        from dulwich.misc import defaultdict
+        import collections
+        collections.defaultdict = defaultdict
+
     optional_plugin_dir = os.path.join(config.root, 'optionalbzrplugins')
     if optional_plugin_dir not in plugins.__path__:
         plugins.__path__.append(optional_plugin_dir)

=== modified file 'lib/canonical/codehosting/codeimport/tests/test_worker.py'
--- lib/canonical/codehosting/codeimport/tests/test_worker.py	2009-03-26 23:38:33 +0000
+++ lib/canonical/codehosting/codeimport/tests/test_worker.py	2009-03-27 00:09:15 +0000
@@ -23,9 +23,9 @@
 from canonical.cachedproperty import cachedproperty
 from canonical.codehosting import load_optional_plugin
 from canonical.codehosting.codeimport.worker import (
-    BazaarBranchStore, CSCVSImportWorker, ForeignTreeStore, GitImportWorker,
-    ImportWorker, get_default_bazaar_branch_store,
-    get_default_foreign_tree_store)
+    BazaarBranchStore, BzrSvnImportWorker, CSCVSImportWorker,
+    ForeignTreeStore, GitImportWorker, ImportWorker,
+    get_default_bazaar_branch_store, get_default_foreign_tree_store)
 from canonical.codehosting.codeimport.tests.test_foreigntree import (
     CVSServer, SubversionServer)
 from canonical.codehosting.tests.helpers import (
@@ -682,5 +682,42 @@
             rcstype='git', git_repo_url=self.repository_path)
 
 
+class TestBzrSvnImport(WorkerTest, TestActualImportMixin):
+
+    def setUp(self):
+        super(TestBzrSvnImport, self).setUp()
+        load_optional_plugin('svn')
+        self.setUpImport()
+
+    def makeImportWorker(self):
+        """Make a new `ImportWorker`."""
+        return BzrSvnImportWorker(
+            self.source_details, self.bazaar_store, logging.getLogger())
+
+    def commitInForeignTree(self, foreign_tree):
+        """Change the foreign tree, generating exactly one commit."""
+        client = pysvn.Client()
+        client.checkout(self.repository_path, 'working_tree')
+        file = open('working_tree/newfile', 'w')
+        file.write('No real content\n')
+        file.close()
+        client.add('working_tree/newfile')
+        client.checkin('working_tree', 'Add a file', recurse=True)
+        shutil.rmtree('working_tree')
+
+    def makeSourceDetails(self, branch_name, files):
+        """Make a SVN `CodeImportSourceDetails` pointing at a real SVN repo.
+        """
+        self.repository_path = self.makeTemporaryDirectory()
+        svn_server = SubversionServer(self.repository_path)
+        svn_server.setUp()
+        self.addCleanup(svn_server.tearDown)
+
+        svn_branch_url = svn_server.makeBranch(branch_name, files)
+        svn_branch_url = svn_branch_url.replace('://localhost/', ':///')
+        return self.factory.makeCodeImportSourceDetails(
+            rcstype='bzr-svn', svn_branch_url=svn_branch_url)
+
+
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)

=== modified file 'lib/canonical/codehosting/codeimport/worker.py'
--- lib/canonical/codehosting/codeimport/worker.py	2009-03-26 23:38:33 +0000
+++ lib/canonical/codehosting/codeimport/worker.py	2009-03-27 00:09:15 +0000
@@ -142,7 +142,7 @@
         """Convert command line-style arguments to an instance."""
         branch_id = int(arguments.pop(0))
         rcstype = arguments.pop(0)
-        if rcstype == 'svn':
+        if rcstype in ['svn', 'bzr-svn']:
             [svn_branch_url] = arguments
             cvs_root = cvs_module = git_repo_url = None
         elif rcstype == 'cvs':
@@ -182,7 +182,7 @@
         """Return a list of arguments suitable for passing to a child process.
         """
         result = [str(self.branch_id), self.rcstype]
-        if self.rcstype == 'svn':
+        if self.rcstype in ['svn', 'bzr-svn']:
             result.append(self.svn_branch_url)
         elif self.rcstype == 'cvs':
             result.append(self.cvs_root)

=== modified file 'lib/canonical/launchpad/testing/factory.py'
--- lib/canonical/launchpad/testing/factory.py	2009-03-25 20:23:31 +0000
+++ lib/canonical/launchpad/testing/factory.py	2009-03-27 00:09:15 +0000
@@ -1224,7 +1224,7 @@
             branch_id = self.getUniqueInteger()
         if rcstype is None:
             rcstype = 'svn'
-        if rcstype == 'svn':
+        if rcstype in ['svn', 'bzr-svn']:
             assert cvs_root is cvs_module is git_repo_url is None
             if svn_branch_url is None:
                 svn_branch_url = self.getUniqueURL()

=== added symlink 'lib/subvertpy'
=== target is '../sourcecode/subvertpy/subvertpy'
=== added symlink 'optionalbzrplugins/svn'
=== target is '../sourcecode/bzr-svn'
=== modified file 'scripts/code-import-worker.py'
--- scripts/code-import-worker.py	2009-03-26 23:38:33 +0000
+++ scripts/code-import-worker.py	2009-03-27 00:09:15 +0000
@@ -20,12 +20,12 @@
 
 from canonical.codehosting import load_optional_plugin
 from canonical.codehosting.codeimport.worker import (
-    CSCVSImportWorker, CodeImportSourceDetails, GitImportWorker,
-    get_default_bazaar_branch_store, get_default_foreign_tree_store)
+    BzrSvnImportWorker, CSCVSImportWorker, CodeImportSourceDetails,
+    GitImportWorker, get_default_bazaar_branch_store,
+    get_default_foreign_tree_store)
 from canonical.launchpad import scripts
 
 
-
 class CodeImportWorker:
 
     def __init__(self):

